==> p5-Curses-UI-0.74.tgz: libdata/perl5/site_perl/Curses/UI/Language/italian.pm <==
# ----------------------------------------------------------------------
# Curses::UI::Language::english
# Maintainer: maurice@gitaar.net
# ----------------------------------------------------------------------

package Curses::UI::Language::italian; 
1;
__DATA__

# ----------------------------------------------------------------------
# For Curses::UI
# ----------------------------------------------------------------------

[screen_too_small]
Il tuo schermo e' troppo piccolo per questa applicazione.
Ridimensionalo ed esegui nuovamente l'applicazione.
Premi <CTRL+C> per uscire...

# ----------------------------------------------------------------------
# For Curses::UI::Calendar
# ----------------------------------------------------------------------

[months]
Gennaio Febbraio Marzo Aprile Maggio Giugno Liglio
Agosto Settembre Ottobre Novembre Dicembre 

[days_short] Do Lu Ma Me Gi Ve Sa

# ----------------------------------------------------------------------
# For Curses::UI::Buttonbox
# ----------------------------------------------------------------------

[button_ok]      o:Conferma
[button_cancel]  c:Annulla
[button_yes]     y:Si
[button_no]      n:No

# ----------------------------------------------------------------------
# For Curses::UI::Dialog::Error
# ----------------------------------------------------------------------

[error_title]    Errore

# ----------------------------------------------------------------------
# For Curses::UI::Dialog::FileBrowser
# ----------------------------------------------------------------------

# The filebrowser title
[file_title]     Selezione un file
[file_savetitle] Selezione un file da salvare  #Select a file to save to
[file_loadtitle] Seleziona un file da aprire   #Select a file to load from

# The labels for the dialog screen.
[file_path]      Percorso :
[file_file]      File :
[file_mask]      Maschera :

# The size of the longest label
[file_labelsize] 10

# On directory up
[file_dirup] Cartella Precedente

# For asking the user if a file may be overwritten
[file_overwrite_title] Conferma
[file_overwrite_question_pre] 
Desideri veramente sovrascrivere il file "
[file_overwrite_question_post] 
"?

# Errors
[file_err_opendir_pre] Impossible aprire la cartella "
[file_err_opendir_post] "
[file_err_nofileselected] Nessun file selezionato!

==> p5-Curses-UI-0.9609p1.tgz: libdata/perl5/site_perl/Curses/UI/Language/italian.pm <==
# ----------------------------------------------------------------------
# Curses::UI::Language::english
# Maintainer: maurice@gitaar.net
# ----------------------------------------------------------------------

package Curses::UI::Language::italian; 
1;
__DATA__

# ----------------------------------------------------------------------
# For Curses::UI
# ----------------------------------------------------------------------

[screen_too_small]
Il tuo schermo e' troppo piccolo per questa applicazione.
Ridimensionalo ed esegui nuovamente l'applicazione.
Premi <CTRL+C> per uscire...

# ----------------------------------------------------------------------
# For Curses::UI::Calendar
# ----------------------------------------------------------------------

[months]
Gennaio Febbraio Marzo Aprile Maggio Giugno Luglio
Agosto Settembre Ottobre Novembre Dicembre 

[days_short] Do Lu Ma Me Gi Ve Sa

# ----------------------------------------------------------------------
# For Curses::UI::Buttonbox
# ----------------------------------------------------------------------

[button_ok]      o:Conferma
[button_cancel]  c:Annulla
[button_yes]     y:Si
[button_no]      n:No

# ----------------------------------------------------------------------
# For Curses::UI::Dialog::Error
# ----------------------------------------------------------------------

[error_title]    Errore

# ----------------------------------------------------------------------
# For Curses::UI::Dialog::FileBrowser
# ----------------------------------------------------------------------

# The filebrowser title
[file_title]     Seleziona un file
[file_savetitle] Seleziona un file da salvare  #Select a file to save to
[file_loadtitle] Seleziona un file da aprire   #Select a file to load from

# The dirbrowser title
[dir_title]      Seleziona una directory

# The labels for the dialog screen.
[file_path]      Percorso :
[file_file]      File :
[file_mask]      Maschera :

# The size of the longest label
[file_labelsize] 10

# On directory up
[file_dirup] Cartella Precedente

# For asking the user if a file may be overwritten
[file_overwrite_title] Conferma
[file_overwrite_question_pre] 
Desideri veramente sovrascrivere il file "
[file_overwrite_question_post] 
"?

# Errors
[file_err_opendir_pre] Impossible aprire la cartella "
[file_err_opendir_post] "
[file_err_nofileselected] Nessun file selezionato!
